@@ -1,6 +1,7 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 set.seed(1234)
 library(INLA)
+if (file.exists("myinit.R")) source("myinit.R")
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
 library(ggplot2)
@@ -21,6 +22,7 @@ opts_chunk$set(size='small'
                , results='hold'
                , eval=TRUE)
 
+
 ## -----------------------------------------------------------------------------
 n = 100
 x = rnorm(n, mean = 1, sd = 0.3)
@@ -30,38 +32,47 @@ r = inla(y ~ 1 + x + xx,
          data = data.frame(y, x, xx), 
 	     family = "poisson")
 
+
 ## -----------------------------------------------------------------------------
 selection = list(Predictor = 3:4, x = 1, xx = 1)
 
+
 ## -----------------------------------------------------------------------------
 rs = inla(y ~ 1 + x + xx,
           data = data.frame(y, x, xx), 
 	      family = "poisson",
+          control.compute = list(return.marginals.predictor = TRUE), 
 	      control.predictor = list(compute = TRUE),
 		  selection = selection)
 
+
 ## -----------------------------------------------------------------------------
 #summary(rs$selection)
 print(rs$selection)
 
+
 ## -----------------------------------------------------------------------------
 ns = 10000
 xs = inla.rjmarginal(ns, rs) ## or rs$selection
 str(xs)
 
+
 ## -----------------------------------------------------------------------------
 pairs(t(xs$samples[, 1:3000]), cex = 0.1)
 
+
 ## -----------------------------------------------------------------------------
 hist(xs$samples["Predictor:3",], n = 300, prob = TRUE, 
      main = 'Histogram of Predictor:3', xlab = 'Samples 
      from the joint and linear predictor marginal (black straight line)')
 lines(inla.smarginal(rs$marginals.linear.predictor[[3]]), lwd = 3)
 
+
 ## -----------------------------------------------------------------------------
 dxs = inla.1djmarginal(jmarginal = rs$selection)
 str(dxs)
 
+
 ## -----------------------------------------------------------------------------
 ggplot(data = data.frame(y = xs$samples["Predictor:3",]), aes(y, after_stat(density), colour = "True")) +
   stat_density(alpha = .1) +
@@ -95,20 +106,24 @@ ggplot(data = data.frame(y = xs$samples["xx:1",]), aes(y, after_stat(density), c
                       breaks = c("True", "Deterministic"),
                       values = c("black", "red"))  
 
+
 ## -----------------------------------------------------------------------------
 summary(rs$selection)
 
+
 ## -----------------------------------------------------------------------------
 A = matrix(c(1,1,0,0,0,0,1,1), nrow = 2, ncol = 4, byrow = T)
 rownames(A) <- c("Test1", "Test2")
 A
 
+
 ## -----------------------------------------------------------------------------
 m = inla.tjmarginal(jmarginal = rs, A = A)
 m
 class(m)
 
 
+
 ## -----------------------------------------------------------------------------
 dxs.lin = inla.1djmarginal(jmarginal = m)
 str(dxs.lin)
@@ -135,9 +150,11 @@ ggplot(data = data.frame(y = xs.lin2[1, ]), aes(y, after_stat(density), colour =
                       breaks = c("True", "Deterministic"),
                       values = c("black", "red")) 
 
+
 ## -----------------------------------------------------------------------------
 summary(m)
 
+
 ## -----------------------------------------------------------------------------
 fun.exp <- function(x) exp(x)
 
@@ -177,6 +194,7 @@ ggplot(data = data.frame(y = tx.lin[1, ]), aes(y, after_stat(density), colour =
                       breaks = c("True", "Deterministic"),
                       values = c("black", "red")) 
 
+
 ## -----------------------------------------------------------------------------
 expx = inla.zmarginal(marginal = tdx, silent = TRUE)
 expxx = inla.zmarginal(marginal = tdxx, silent = TRUE)
