@@ -1,29 +1,35 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 library(INLA)
+if (file.exists("myinit.R")) source("myinit.R")
 inla.setOption(smtp='taucs')
 inla.setOption(num.threads="1:1")
 knitr::opts_chunk$set(fig.path="figures/old-faq/")
 set.seed(123)
 source("render_toc.R")
 
+
 ## ----toc, echo=FALSE----------------------------------------------------------
 render_toc("old-faq.Rmd")
 
+
 ## ---- eval=FALSE--------------------------------------------------------------
-#      expression: statement; statement; ...; return(value)
+##     expression: statement; statement; ...; return(value)
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#      prior.expression = "expression:
-#          a = 1;
-#          b = 0.1;
-#          precision = exp(log_precision);
-#          logdens = log(b^a) - lgamma(a)
-#             + (a-1)*log_precision - b*precision;
-#          log_jacobian = log_precision;
-#          return(logdens + log_jacobian);"
+##     prior.expression = "expression:
+##         a = 1;
+##         b = 0.1;
+##         precision = exp(log_precision);
+##         logdens = log(b^a) - lgamma(a)
+##            + (a-1)*log_precision - b*precision;
+##         log_jacobian = log_precision;
+##         return(logdens + log_jacobian);"
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#      table: x_1 ... x_n y_1 ... y_n
+##     table: x_1 ... x_n y_1 ... y_n
+
 
 ## -----------------------------------------------------------------------------
 ## the loggamma-prior
@@ -74,6 +80,7 @@ r3 = inla(y~1, data = data.frame(y),
 
 print(round(c(r1$mlik[1], r2$mlik[1], r3$mlik[1]), dig=3))
 
+
 ## -----------------------------------------------------------------------------
 n = 100
 z = rnorm(n)
@@ -98,6 +105,7 @@ rrr = inla(y ~ 1 + z,  data = data.frame(y, z), family = "binomial", Ntrials = r
         control.family = list(control.link = list(model="cloglog")), 
 		control.predictor = list(compute=TRUE))        
 
+
 ## -----------------------------------------------------------------------------
 n = 100
 n.pred = 10
@@ -109,9 +117,11 @@ formula = yy ~ f(i, model="ar1")
 r = inla(formula, data = data.frame(i,yy),
         control.family = list(initial = 10, fixed=TRUE)) ## no observational noise
 
+
 ## -----------------------------------------------------------------------------
 r$summary.random$i[(n+1):N, c("mean", "sd") ]
 
+
 ## ----plot=TRUE----------------------------------------------------------------
 ## simple poisson regression
 n = 100
@@ -133,6 +143,7 @@ r = inla(y ~ 1 + x,  family = "poisson",
 plot(exp(eta),type ="l")
 points(r$summary.fitted.values$mean, pch=19)
 
+
 ## ----plot=T-------------------------------------------------------------------
 n2 = n %/% 2L
 Y = matrix(NA, n, 2)
@@ -148,6 +159,7 @@ r = inla(Y ~ 1 + x,  family = c("poisson", "nbinomial"),
 plot(exp(eta),type ="l")
 points(r$summary.fitted.values$mean, pch=19)
 
+
 ## -----------------------------------------------------------------------------
 ## Load the data
 data(Tokyo)
@@ -163,6 +175,7 @@ formula = y ~ f(time, model="rw2", scale.model=TRUE,
 
 ## We'll get a warning since we have not defined the link argument
 result = inla(formula, family="binomial", Ntrials=n, data=Tokyo,
+	control.compute = list(return.marginals.predictor = TRUE), 
 	control.predictor=list(compute=T))
 
 ## need to recompute the fitted values for those with data[i] = NA,
@@ -189,71 +202,90 @@ for(i in 1:366) {
 }
 plot(fitted.values.mean)
 
+
 ## ---- eval=FALSE--------------------------------------------------------------
-#  4
-#  1 2 3 4
-#  2 0
-#  3 1 1
-#  4 1 1
+## 4
+## 1 2 3 4
+## 2 0
+## 3 1 1
+## 4 1 1
+
 
 ## ----plot=TRUE,fig.width=2,fig.align='center'---------------------------------
 g = inla.read.graph("4 1 2 3 4 2 0 3 1 1 4 1 1")
 plot(g)
 
-## ----eval=FALSE---------------------------------------------------------------
-#  "4 1 2 3 4  2 0 3 1 1 4 1 1"
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  formula = y ~ f(idx, model = "besag", graph = "graph.dat")
+## "4 1 2 3 4  2 0 3 1 1 4 1 1"
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  formula = y ~ f(idx, model = "besag", graph = "4 1 2 3 4  2 0 3 1 1 4 1 1")
+## formula = y ~ f(idx, model = "besag", graph = "graph.dat")
+
+
+## ----eval=FALSE---------------------------------------------------------------
+## formula = y ~ f(idx, model = "besag", graph = "4 1 2 3 4  2 0 3 1 1 4 1 1")
+
 
 ## -----------------------------------------------------------------------------
 C = matrix(c(1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 0, 1),4,4)
 C
 
+
 ## -----------------------------------------------------------------------------
 C.sparse= inla.as.sparse(C)
 C.sparse
 
+
 ## -----------------------------------------------------------------------------
 str(g)
 
+
 ## ----eval=FALSE---------------------------------------------------------------
-#  formula = y ~ x + f(k, model= <some model>)
+## formula = y ~ x + f(k, model= <some model>)
+
 
 ## ----eval=F-------------------------------------------------------------------
-#  control.fixed = list(expand.factor.strategy = "inla")
+## control.fixed = list(expand.factor.strategy = "inla")
+
 
 ## -----------------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3, x=factor(c("a","b","c"))))
 as.matrix(r$model.matrix)
 
+
 ## -----------------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3,x=factor(c("a","b","c"))), 
          control.fixed = list(expand.factor.strategy="inla"))
 as.matrix(r$model.matrix)
 
+
 ## -----------------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3,x=factor(c("a","b",NA))), 
          control.fixed = list(expand.factor.strategy="inla"))
 as.matrix(r$model.matrix)
 
-## ----eval=FALSE---------------------------------------------------------------
-#  control.compute=list(cpo=TRUE)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  improved.result = inla.cpo(result)
+## control.compute=list(cpo=TRUE)
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  r = inla(..., inla.call = "submit")
+## improved.result = inla.cpo(result)
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  inla.qstat()
+## r = inla(..., inla.call = "submit")
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  r = inla.qget(r)
+## inla.qstat()
+
+
+## ----eval=FALSE---------------------------------------------------------------
+## r = inla.qget(r)
+
 
 ## -----------------------------------------------------------------------------
 ## A simple model
@@ -291,6 +323,7 @@ lc1.1 = 2 * r$summary.fixed["a", "mean"] + 3 * r$summary.fixed["b",
 lc1.2= r$summary.lincomb.derived$mean
 print(round(c(lc1.1 = lc1.1, lc1.2 = lc1.2), dig=3))
 
+
 ## -----------------------------------------------------------------------------
 ## let wa and wb be vectors, and we want to compute the marginals for
 ## beta_a * wa[i] + beta_b * wb[i], for i=1..m. this is done
@@ -308,11 +341,14 @@ r = inla(formula, data = data.frame(a,b,y),
         control.family = list(initial=10, fixed=TRUE))
 print(round(r$summary.lincomb.derived, dig=3))
 
-## ----eval=FALSE---------------------------------------------------------------
-#  control.inla = list(lincomb.derived.correlation.matrix = TRUE)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  result$misc$lincomb.derived.correlation.matrix
+## control.inla = list(lincomb.derived.correlation.matrix = TRUE)
+
+
+## ----eval=FALSE---------------------------------------------------------------
+## result$misc$lincomb.derived.correlation.matrix
+
 
 ## -----------------------------------------------------------------------------
 n = 100
@@ -339,6 +375,7 @@ r = inla(formula,  data = data.frame(Y, time),
 
 print(round(r$misc$lincomb.derived.correlation.matrix,dig=3))
 
+
 ## -----------------------------------------------------------------------------
 n = 100
 u = rnorm(n)
@@ -354,6 +391,7 @@ result = inla(y ~ 1 + f(idx, model="iid",
 	          Ntrials = 1)
 summary(result)
 
+
 ## -----------------------------------------------------------------------------
 ## simple example
 n = 100
@@ -417,19 +455,24 @@ r = inla(formula,
 
 summary(r)
 
+
 ## -----------------------------------------------------------------------------
 inla.list.models()
 
-## ----eval=FALSE---------------------------------------------------------------
-#  y = a + b*w + ...
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  f(idx, model="iid2d", n=2*m, ...)
+## y = a + b*w + ...
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  idx = 1:m
-#  idx.copy = m + 1:m
-#  formula = y ~  f(idx, model="iid2d", n=2*m) + f(idx.copy, w, copy="idx") + ....
+## f(idx, model="iid2d", n=2*m, ...)
+
+
+## ----eval=FALSE---------------------------------------------------------------
+## idx = 1:m
+## idx.copy = m + 1:m
+## formula = y ~  f(idx, model="iid2d", n=2*m) + f(idx.copy, w, copy="idx") + ....
+
 
 ## -----------------------------------------------------------------------------
 n=1000
@@ -443,20 +486,25 @@ formula = y ~ f(i, model="iid",initial=0, fixed=T) +
 r = inla(formula, data = data.frame(i,j,w,y))
 summary(r)
 
-## ----eval=FALSE---------------------------------------------------------------
-#  beta = low + (high-low)*exp(beta.local)/(1+exp(beta.local))
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  f(idx, model = ..,  replicate = r)
+## beta = low + (high-low)*exp(beta.local)/(1+exp(beta.local))
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  i = 1:n
-#  formula = y ~  f(i, model = "iid") + ...
+## f(idx, model = ..,  replicate = r)
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  i = rep(1,n)
-#  r = 1:n
-#  formula = y ~  f(i, model="iid", replicate = r) + ...
+## i = 1:n
+## formula = y ~  f(i, model = "iid") + ...
+
+
+## ----eval=FALSE---------------------------------------------------------------
+## i = rep(1,n)
+## r = 1:n
+## formula = y ~  f(i, model="iid", replicate = r) + ...
+
 
 ## -----------------------------------------------------------------------------
 n = 100
@@ -474,8 +522,10 @@ result = inla(formula, family = "gaussian",
               control.family = list(initial = 12, fixed=TRUE))
 summary(result)
 
+
 ## ----eval=FALSE---------------------------------------------------------------
-#  y ~ a + 1
+## y ~ a + 1
+
 
 ## -----------------------------------------------------------------------------
 ##  Simple linear regression with observations with two different
@@ -501,6 +551,7 @@ result = inla(
                             list()))
 summary(result)
 
+
 ## -----------------------------------------------------------------------------
 ## Simple example with two types of likelihoods
 n = 10
@@ -548,16 +599,18 @@ result = inla(formula,
         E = E, Ntrials = Ntrials)
 summary(result)
 
+
 ## ----eval=FALSE---------------------------------------------------------------
-#  X = numeric(N)
-#  X[1:n] = x
-#  X[1:n + n] = NA
-#  
-#  XX = numeric(N)
-#  XX[1:n] = NA
-#  XX[1:n + n] = xx
-#  
-#  formula = Y  ~ X + XX -1
+## X = numeric(N)
+## X[1:n] = x
+## X[1:n + n] = NA
+## 
+## XX = numeric(N)
+## XX[1:n] = NA
+## XX[1:n + n] = xx
+## 
+## formula = Y  ~ X + XX -1
+
 
 ## -----------------------------------------------------------------------------
 ## An example with three independent AR(1)'s with separate means, but
@@ -607,26 +660,33 @@ result = inla(formula, family = c("binomial", "poisson", "normal"),
                       list()))
 summary(result)
 
-## ----eval=FALSE---------------------------------------------------------------
-#  y ~ 1 + z
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  eta~ = A %*% eta
+## y ~ 1 + z
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  y ~ 1 + z, with addition matrix A
+## eta~ = A %*% eta
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  y    ~ eta~   ## no intercept...
-#  eta~ = A %*% eta
-#  eta  = intercept + beta*z
+## y ~ 1 + z, with addition matrix A
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  control.predictor=list(A=A)
+## y    ~ eta~   ## no intercept...
+## eta~ = A %*% eta
+## eta  = intercept + beta*z
+
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  eta~ = A %*% eta + offset.arg
-#  eta = intercept + beta*z + offset.formula
+## control.predictor=list(A=A)
+
+
+## ----eval=FALSE---------------------------------------------------------------
+## eta~ = A %*% eta + offset.arg
+## eta = intercept + beta*z + offset.formula
+
 
 ## -----------------------------------------------------------------------------
 ## 'm' is the number of observations of eta*, where eta* = A eta +
@@ -675,8 +735,10 @@ summary(r)
 ## this should be a small number
 print(max(abs(r$summary.linear.predictor$mean - c(Eta, eta))))
 
+
 ## ----eval=FALSE---------------------------------------------------------------
-#  y = intercept + s[j] + 0.5*s[k] + noise
+## y = intercept + s[j] + 0.5*s[k] + noise
+
 
 ## ----plot=TRUE----------------------------------------------------------------
 n = 100
